####################
ROD-4 MFC Controller
####################

.. autoclass:: pymeasure.instruments.proterial.ROD4
    :members:
    :show-inheritance:
    :inherited-members: CommonBase

.. autoclass:: pymeasure.instruments.proterial.rod4.ROD4Channel
    :members:
    :show-inheritance: